To ensure the proper configuration of the AWS S3 bucket:

-   Ensure public access is required, if not, restrict access to
    authorized users only.
-   If public access is required, ensure that file listing is required,
    if not, remove list object permission from all users access.
-   If public access is required, ensure that no sensitive information
    is stored in the bucket.
